@@ -60,6 +60,7 @@ class YAML(object):
                             "one was given ({!r})".format(self.__class__.__name__, _kw))
 
         self.typ = 'rt' if typ is None else typ
+        self.pure = pure
         self.plug_ins = []  # type: List[Any]
         for pu in ([] if plug_ins is None else plug_ins) + self.official_plug_ins():
             file_name = pu.replace('/', '.')
@@ -340,7 +341,6 @@ class YAML(object):
         # type: (Any, StreamType, Any, Any) -> Any
         """
         Serialize a sequence of Python objects into a YAML stream.
-        If stream is None, return the produced string instead.
         """
         if not hasattr(stream, 'write') and hasattr(stream, 'open'):
             # pathlib.Path() instance
@@ -419,9 +419,9 @@ class YAML(object):
                                   explicit_end=explicit_end,
                                   version=version, tags=tags)
                 selfx._emitter = selfx._serializer = selfx._representer = selfx
-                Representer.__init__(selfx, default_style=default_style,
-                                     default_flow_style=default_flow_style)
-                Resolver.__init__(selfx)
+                self.Representer.__init__(selfx, default_style=default_style,
+                                          default_flow_style=default_flow_style)
+                rslvr.__init__(selfx)
         self._stream = stream
         dumper = XDumper(stream)
         self._emitter = self._serializer = dumper
